The mpi_array.distribution Module¶
Apportionment of arrays over locales.
Classes¶
GlobaleExtent([slice, start, stop, halo, struct]) |
Indexing extent for an entire globale array. |
HaloSubExtent([globale_extent, slice, halo, ...]) |
Indexing extent for single region of a larger globale extent. |
LocaleExtent([peer_rank, inter_locale_rank, ...]) |
Indexing extent for single region of array residing on a locale. |
CartLocaleExtent([peer_rank, ...]) |
Indexing extents for single tile of cartesian domain distribution. |
Distribution(globale_extent, locale_extents) |
Describes the apportionment of array extents amongst locales. |
ClonedDistribution(globale_extent, num_locales) |
Distribution where entire globale extent elements occur on every locale. |
SingleLocaleDistribution(globale_extent, ...) |
Distribution where entire globale extent elements occur on just a single locale. |
BlockPartition(globale_extent, dims, ...[, ...]) |
Block partition of an array (shape) over locales. |