get_dtype_and_ndim(array_like) |
Returns (dtype, ndim) pair for the given array_like argument. |
ufunc_result_type(ufunc_types, inputs[, ...]) |
Attempts to calculate the result type from given ufunc inputs and ufunc types (numpy.ufunc.types). |
broadcast_shape(*shape_args) |
Returns the numpy broadcast shape for the give shape arguments. |
shape_extend_dims(ndim, shape) |
Returns shape pre-prepended with ones so returned 1D array has length ndim. |
gndarray_array_ufunc(array_like_obj, ufunc, ...) |
The implementation for mpi_array.globale.gndarray.__array_ufunc__(). |