The mpi_array.init Module¶
Initialisation which needs to occur prior to MPI_Init.
Parts of this source borrows from the airspeed velocity (asv) file benchmark.py.
See the LICENSE.
Functions¶
create_linux_process_time() |
Uses ctypes to create a time.process_time() on the 'Linux' platform. |
create_darwin_process_time() |
Uses ctypes to create a time.process_time() on the 'darwin' (OSX) platform. |
initialise_process_time_timer() |
Loads (or creates) time.process_time() function and caches the function in mpi_array.init._process_time. |
get_process_time_timer() |
The best timer we can use is time.process_time(), but it is not available in the Python stdlib until Python 3.3. |