The mpi_array.locale Module¶
Defines LndarrayProxy class and factory functions for
creating multi-dimensional arrays where memory is allocated
using mpi4py.MPI.Win.Allocate_shared() or mpi4py.MPI.Win.Allocate().
Classes¶
lndarray |
Sub-class of numpy.ndarray which requires buffer to be specified for instantiation. |
LndarrayProxy |
Proxy for lndarray instances. |
PartitionViewSlices |
Stores multiple tuple-of-slice objects indicating the slice (tile) of the lndarray on which a intra_locale_comm rank MPI process operates. |
Factory Functions¶
empty([shape, dtype, comms_and_distrib, ...]) |
Creates array of uninitialised elements. |
empty_like(ary[, dtype]) |
Return a new array with the same shape and type as a given array. |
zeros([shape, dtype, comms_and_distrib, order]) |
Creates array of zero-initialised elements. |
zeros_like(ary, *args, **kwargs) |
Return a new zero-initialised array with the same shape and type as a given array. |
ones([shape, dtype, comms_and_distrib, order]) |
Creates array of one-initialised elements. |
ones_like(ary, *args, **kwargs) |
Return a new one-initialised array with the same shape and type as a given array. |
copy(ary) |
Return an array copy of the given object. |
Utilities¶
NdarrayMetaData(offset, strides, order) |
Encapsulates, strides, offset and order argument of LndarrayProxy.__new__(). |