The mpi_array.update Module¶
Helper classes for calculating sub-extent intersections in order to perform remote array element copying/updates.
Classes and Functions¶
ExtentAndRegion(locale_extent[, region_extent]) |
Container for mpi_array.distribution.LocaleExtent and an update region (mpi_array.indexing.IndexingExtent). |
MpiExtentAndRegion(locale_extent, region_extent) |
|
ExtentUpdate(dst_extent_info, src_extent_info) |
Source and destination indexing info for updating a sub-extent region. |
PairExtentUpdate(dst_extent, src_extent, ...) |
Source and destination indexing info for updating a sub-extent region. |
MpiPairExtentUpdate(dst_extent, src_extent, ...) |
Source and destination indexing info for updating the whole of a halo portion. |
MpiPairExtentUpdateDifferentDtypes(...) |
Over-rides MpiPairExtentUpdate.do_get() to buffer-copy and subsequent casting when source and destination arrays have different numpy.dtype. |
HaloSingleExtentUpdate(dst_extent, ...) |
Source and destination indexing info for updating a halo portion. |
MpiHaloSingleExtentUpdate(dst_extent, ...) |
Source and destination indexing info for updating the whole of a halo portion. |
UpdatesForRedistribute(dst_distrib, src_distrib) |
Collection of update extents for re-distribution of array elements from one distribution to another. |
RmaUpdateExecutor(inter_win, dst_lndarray, ...) |
Performs one-sided fetch of data from remote (source) locale arrays to update destination locale array. |